<?php

/**
 * This is the model class for table "user".
 *
 * The followings are the available columns in table 'user':
 * @property integer $u_id
 * @property string $u_identity
 * @property string $u_provider
 * @property string $u_email
 * @property string $u_full_name
 * @property integer $u_state
 *
 * The followings are the available model relations:
 */
class User extends CActiveRecord
{
	/**
	 * Returns the static model of the specified AR class.
	 * @return User the static model class
	 */
	public static function model($className=__CLASS__)
	{
		return parent::model($className);
	}

	/**
	 * @return string the associated database table name
	 */
	public function tableName()
	{
		return 'user';
	}

	/**
	 * @return array validation rules for model attributes.
	 */
	public function rules()
	{
		// NOTE: you should only define rules for those attributes that
		// will receive user inputs.
		return array(
			array('u_identity, u_provider, u_state', 'required'),
			array('u_state', 'numerical', 'integerOnly'=>true),
			array('u_identity, u_provider, u_email', 'length', 'max'=>255),
			array('u_full_name', 'length', 'max'=>55),
			// The following rule is used by search().
			// Please remove those attributes that should not be searched.
			array('u_id, u_identity, u_provider, u_email, u_full_name, u_state', 'safe', 'on'=>'search'),
		);
	}

	/**
	 * @return array relational rules.
	 */
	public function relations()
	{
		// NOTE: you may need to adjust the relation name and the related
		// class name for the relations automatically generated below.
		return array(
		);
	}

	/**
	 * @return array customized attribute labels (name=>label)
	 */
	public function attributeLabels()
	{
		return array(
			'u_id' => 'U',
			'u_identity' => 'U Identity',
			'u_provider' => 'U Provider',
			'u_email' => 'U Email',
			'u_full_name' => 'U Full Name',
			'u_state' => 'U State',
		);
	}

	/**
	 * Retrieves a list of models based on the current search/filter conditions.
	 * @return CActiveDataProvider the data provider that can return the models based on the search/filter conditions.
	 */
	public function search()
	{
		// Warning: Please modify the following code to remove attributes that
		// should not be searched.

		$criteria=new CDbCriteria;

		$criteria->compare('u_id',$this->u_id);
		$criteria->compare('u_identity',$this->u_identity,true);
		$criteria->compare('u_provider',$this->u_provider,true);
		$criteria->compare('u_email',$this->u_email,true);
		$criteria->compare('u_full_name',$this->u_full_name,true);
		$criteria->compare('u_state',$this->u_state);

		return new CActiveDataProvider(get_class($this), array(
			'criteria'=>$criteria,
		));
	}

	public function  beforeValidate() {
		$this->u_state = 1;
		parent::beforeValidate();
		return TRUE;
	}
}